==> isa-l_crypto-2.24.0.tar.gz: isa-l_crypto-2.24.0/aes/aarch64/keyexp_aarch64_dispatcher.c <==
/**********************************************************************
  Copyright(c) 2020 Arm Corporation All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the
      distribution.
    * Neither the name of Arm Corporation nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**********************************************************************/
#include <aarch64_multibinary.h>

#undef PROVIDER_BASIC
#define PROVIDER_BASIC(a) (void*)0

DEFINE_INTERFACE_DISPATCHER(aes_keyexp_128)
{
	unsigned long auxval = getauxval(AT_HWCAP);
	if ((auxval & (HWCAP_ASIMD | HWCAP_AES)) == (HWCAP_ASIMD | HWCAP_AES))
		return PROVIDER_INFO(aes_keyexp_128_aes);

	return PROVIDER_BASIC(aes_keyexp_128);

}

DEFINE_INTERFACE_DISPATCHER(aes_keyexp_128_enc)
{
	unsigned long auxval = getauxval(AT_HWCAP);
	if ((auxval & (HWCAP_ASIMD | HWCAP_AES)) == (HWCAP_ASIMD | HWCAP_AES))
		return PROVIDER_INFO(aes_keyexp_128_enc_aes);

	return PROVIDER_BASIC(aes_keyexp_128_enc);

}

DEFINE_INTERFACE_DISPATCHER(aes_keyexp_192)
{
	unsigned long auxval = getauxval(AT_HWCAP);
	if ((auxval & (HWCAP_ASIMD | HWCAP_AES)) == (HWCAP_ASIMD | HWCAP_AES))
		return PROVIDER_INFO(aes_keyexp_192_aes);

	return PROVIDER_BASIC(aes_keyexp_192);

}

DEFINE_INTERFACE_DISPATCHER(aes_keyexp_256)
{
	unsigned long auxval = getauxval(AT_HWCAP);
	if ((auxval & (HWCAP_ASIMD | HWCAP_AES)) == (HWCAP_ASIMD | HWCAP_AES))
		return PROVIDER_INFO(aes_keyexp_256_aes);

	return PROVIDER_BASIC(aes_keyexp_256);

}

==> isa-l_crypto-2.25.0.tar.gz: isa-l_crypto-2.25.0/aes/aarch64/keyexp_aarch64_dispatcher.c <==
/**********************************************************************
  Copyright(c) 2020 Arm Corporation All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the
      distribution.
    * Neither the name of Arm Corporation nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**********************************************************************/
#include <aarch64_multibinary.h>

#undef PROVIDER_BASIC
#define PROVIDER_BASIC(a) (void *) 0

DEFINE_INTERFACE_DISPATCHER(_aes_keyexp_128)
{
        unsigned long auxval = getauxval(AT_HWCAP);
        if ((auxval & (HWCAP_ASIMD | HWCAP_AES)) == (HWCAP_ASIMD | HWCAP_AES))
                return PROVIDER_INFO(aes_keyexp_128_aes);

        return PROVIDER_BASIC(_aes_keyexp_128);
}

DEFINE_INTERFACE_DISPATCHER(aes_keyexp_128_enc)
{
        unsigned long auxval = getauxval(AT_HWCAP);
        if ((auxval & (HWCAP_ASIMD | HWCAP_AES)) == (HWCAP_ASIMD | HWCAP_AES))
                return PROVIDER_INFO(aes_keyexp_128_enc_aes);

        return PROVIDER_BASIC(aes_keyexp_128_enc);
}

DEFINE_INTERFACE_DISPATCHER(_aes_keyexp_192)
{
        unsigned long auxval = getauxval(AT_HWCAP);
        if ((auxval & (HWCAP_ASIMD | HWCAP_AES)) == (HWCAP_ASIMD | HWCAP_AES))
                return PROVIDER_INFO(aes_keyexp_192_aes);

        return PROVIDER_BASIC(_aes_keyexp_192);
}

DEFINE_INTERFACE_DISPATCHER(_aes_keyexp_256)
{
        unsigned long auxval = getauxval(AT_HWCAP);
        if ((auxval & (HWCAP_ASIMD | HWCAP_AES)) == (HWCAP_ASIMD | HWCAP_AES))
                return PROVIDER_INFO(aes_keyexp_256_aes);

        return PROVIDER_BASIC(_aes_keyexp_256);
}
